@@ -1104,6 +1104,7 @@ Ensure (agent_controller, delete_agents_fails_on_http_422)
 int
 main (int argc, char **argv)
 {
+  int ret;
   TestSuite *suite = create_test_suite ();
 
   add_test_with_context (suite, agent_controller,
@@ -1226,6 +1227,10 @@ main (int argc, char **argv)
                          delete_agents_fails_on_http_422);
 
   if (argc > 1)
-    return run_single_test (suite, argv[1], create_text_reporter ());
-  return run_test_suite (suite, create_text_reporter ());
+    ret = run_single_test (suite, argv[1], create_text_reporter ());
+  ret = run_test_suite (suite, create_text_reporter ());
+
+  destroy_test_suite (suite);
+
+  return ret;
 }
\ No newline at end of file
