@@ -297,6 +297,7 @@ Ensure (cpeutils, uri_cpe_to_uri_product)
 int
 main (int argc, char **argv)
 {
+  int ret;
   TestSuite *suite;
 
   suite = create_test_suite ();
@@ -311,7 +312,10 @@ main (int argc, char **argv)
   add_test_with_context (suite, cpeutils, uri_cpe_to_uri_product);
 
   if (argc > 1)
-    return run_single_test (suite, argv[1], create_text_reporter ());
+    ret = run_single_test (suite, argv[1], create_text_reporter ());
+  ret = run_test_suite (suite, create_text_reporter ());
 
-  return run_test_suite (suite, create_text_reporter ());
+  destroy_test_suite (suite);
+
+  return ret;
 }
