@@ -217,6 +217,7 @@ Ensure (json, gvm_json_obj_check_int_0_and_val_when_has)
 int
 main (int argc, char **argv)
 {
+  int ret;
   TestSuite *suite;
 
   suite = create_test_suite ();
@@ -246,6 +247,10 @@ main (int argc, char **argv)
                          gvm_json_obj_check_str_0_and_val_when_has);
 
   if (argc > 1)
-    return run_single_test (suite, argv[1], create_text_reporter ());
-  return run_test_suite (suite, create_text_reporter ());
+    ret = run_single_test (suite, argv[1], create_text_reporter ());
+  ret = run_test_suite (suite, create_text_reporter ());
+
+  destroy_test_suite (suite);
+
+  return ret;
 }
