@@ -55,6 +55,7 @@ Ensure (kb, parse_port_of_addr_v6)
 int
 main (int argc, char **argv)
 {
+  int ret;
   TestSuite *suite;
 
   suite = create_test_suite ();
@@ -64,7 +65,10 @@ main (int argc, char **argv)
   add_test_with_context (suite, kb, parse_port_of_addr_v6);
 
   if (argc > 1)
-    return run_single_test (suite, argv[1], create_text_reporter ());
+    ret = run_single_test (suite, argv[1], create_text_reporter ());
+  ret = run_test_suite (suite, create_text_reporter ());
 
-  return run_test_suite (suite, create_text_reporter ());
+  destroy_test_suite (suite);
+
+  return ret;
 }
