@@ -51,6 +51,7 @@ Ensure (mqtt, mqtt_client_destroy_nulls_client)
 int
 main (int argc, char **argv)
 {
+  int ret;
   TestSuite *suite;
 
   suite = create_test_suite ();
@@ -58,7 +59,10 @@ main (int argc, char **argv)
   add_test_with_context (suite, mqtt, mqtt_client_destroy_nulls_client);
 
   if (argc > 1)
-    return run_single_test (suite, argv[1], create_text_reporter ());
+    ret = run_single_test (suite, argv[1], create_text_reporter ());
+  ret = run_test_suite (suite, create_text_reporter ());
 
-  return run_test_suite (suite, create_text_reporter ());
+  destroy_test_suite (suite);
+
+  return ret;
 }
