@@ -115,6 +115,7 @@ Ensure (PBA, handle_md5_hash)
 int
 main (int argc, char **argv)
 {
+  int ret;
   TestSuite *suite;
 
   suite = create_test_suite ();
@@ -130,7 +131,12 @@ main (int argc, char **argv)
   add_test_with_context (suite, PBA, handle_md5_hash);
   add_test_with_context (suite, PBA, defaults);
   add_test_with_context (suite, PBA, initialization);
+
   if (argc > 1)
-    return run_single_test (suite, argv[1], create_text_reporter ());
-  return run_test_suite (suite, create_text_reporter ());
+    ret = run_single_test (suite, argv[1], create_text_reporter ());
+  ret = run_test_suite (suite, create_text_reporter ());
+
+  destroy_test_suite (suite);
+
+  return ret;
 }
